from .._pysiclib.numerical import *
from typing import Any

def initial_value_problem(system_of_eqs, inital_conditions, target_value, initial_value: float = ...): ...
def integral_index_interval(input_array, start_index: int = ..., end_index: Any | None = ...): ...
def equation_solution(equation_as_function, target_val, precision: int = ...): ...
