from typing import Any, Callable, Optional

def derivative_at_index(arg0, arg1: int) -> float: ...
def equation_solution(arg0: Callable[[float],float], arg1: float) -> Optional[float]: ...
def initial_value_problem(*args, **kwargs) -> Any: ...
def integral_index_interval(arg0, arg1: int, arg2: int) -> float: ...
